/*
 * A generic page mapper providing memory pages to satisfy file accesses.
 *
 * Copyright (C) 2021, 2022 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#pragma once

#include <mem/flexpage.h>



/* A generic file mapper interface, accessed by the pager, associating flexpages
   with file regions. */

class GenericPageMapper
{
public:
    virtual ~GenericPageMapper();

    virtual Flexpage *get(offset_t offset, map_flags_t flags);

    virtual void queue(Flexpage *flexpage);

    virtual void flush_all(offset_t start, offset_t size);

    virtual offset_t get_data_size();

    virtual void set_data_size(offset_t size);
};

// vim: tabstop=4 expandtab shiftwidth=4
